@@ -1,17 +1,17 @@
 import logging
 import re
 import shutil
-import sys
 
 import pandas
 
+import sys
 import lcbuilder.eleanor
-import numpy as np
-from astropy.coordinates import SkyCoord
-
 sys.modules['eleanor'] = sys.modules['lcbuilder.eleanor']
 import eleanor
 from lcbuilder.eleanor.targetdata import TargetData
+
+import numpy as np
+from astropy.coordinates import SkyCoord
 from lcbuilder import constants
 from lcbuilder.LcBuild import LcBuild
 from lcbuilder.constants import CUTOUT_SIZE, LIGHTKURVE_CACHE_DIR, ELEANOR_CACHE_DIR
@@ -38,7 +38,7 @@ class MissionLightcurveBuilder(LightcurveBuilder):
         if mission_prefix not in self.star_catalogs:
             raise ValueError("Wrong object id " + mission_id)
         cadence = object_info.cadence if object_info.cadence is not None else "short"
-        author_extension = '_long' if cadence >= 600 and mission == constants.MISSION_TESS else ''
+        author_extension = '_long' if isinstance(cadence, (int, float)) and cadence >= 600 and mission == constants.MISSION_TESS else ''
         author = object_info.author if object_info.author is not None else self.authors[mission + author_extension]
         logging.info("Downloading lightcurve files...")
         sectors = None if object_info.sectors == 'all' or mission != constants.MISSION_TESS else object_info.sectors
@@ -57,7 +57,8 @@ class MissionLightcurveBuilder(LightcurveBuilder):
         if not os.path.exists(tpfs_dir):
             os.mkdir(tpfs_dir)
         if object_info.apertures is None:
-            if cadence >= 600 and mission_prefix == constants.MISSION_ID_TESS and author == constants.ELEANOR_AUTHOR:
+            if isinstance(cadence, (int, float)) and cadence >= 600 and \
+                    mission_prefix == constants.MISSION_ID_TESS and author == constants.ELEANOR_AUTHOR:
                 source = "eleanor"
                 if object_info.ra is not None and object_info.dec is not None:
                     coords = SkyCoord(ra=object_info.ra, dec=object_info.dec, unit=(u.deg, u.deg))
